@@ -13,7 +13,7 @@ import termios
 import time
 from contextlib import contextmanager
 
-__version__ = '5.3.1'
+__version__ = '5.4.0'
 
 AUDIO_EXTENSIONS = [
     'mp3', 'ogg', 'oga', 'opus', 'flac', 'm4a', 'm4b', 'wav', 'mid', 'wma'
@@ -44,6 +44,7 @@ Filelist
 a            : add to playlist
 s            : recursive search
 BS           : go to parent dir
+r            : refresh
 
 Playlist
 --------
@@ -96,7 +97,7 @@ def get_socket(path):
 @functools.cache
 def get_mpv_version():
     p = subprocess.run(['mpv', '--version'], stdout=subprocess.PIPE)
-    s = p.stdout.split(b' ', 2)[1].decode()
+    s = p.stdout.split(b' ', 2)[1].decode().lstrip('v')
     return tuple(int(i) for i in s.split('.'))
 
 
@@ -420,12 +421,14 @@ class Filelist(List):
             s += '/'
         return s
 
-    def set_path(self, path, prev=None):
+    def set_path(self, path, *, prev=None, refresh=False):
         if path != self.path:
             self.path = path
             os.chdir(path)
             relpath.cache_clear()
             self.search_cache = []
+        elif refresh:
+            self.search_cache = []
         self.all_items = []
         self.rsearch_str = ''
 
@@ -494,6 +497,8 @@ class Filelist(List):
         elif key == '\n':
             if self.items:
                 self.activate(self.items[self.cursor])
+        elif key == 'r':
+            self.set_path(self.path, refresh=True)
         elif key == curses.KEY_BACKSPACE:
             if self.rsearch_str:
                 self.set_path(self.path)
@@ -798,12 +803,20 @@ class Application:
             sel.register(sys.stdin, selectors.EVENT_READ)
             sel.register(self.resize_in, selectors.EVENT_READ)
             sel.register(player.socket, selectors.EVENT_READ)
+            prev = time.time()
 
             while True:
                 player.finish_seek()
 
                 timeout = 0.5 if player.is_playing else None
                 for key, _mask in sel.select(timeout):
+                    # if we have skipped multiple seconds, it is probably
+                    # because the system was suspended. This heuristic is much
+                    # simpler than detecting suspend via dbus.
+                    if player.is_playing and time.time() - prev > 5:
+                        player.stop()
+                    prev = time.time()
+
                     if key.fileobj is self.resize_in:
                         os.read(self.resize_in, 8)
                         self.on_resize()
